/* Copyright (C) 2023 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Sergey Gorbunov [committer] */

#include "CbmL1Util.h"

#include "FairTrackParam.h"

namespace cbm::L1Util
{

  void CopyTC2TrackParam(FairTrackParam* par, Double_t T[], Double_t C[])
  {
    if (T) {
      par->SetX(T[0]);
      par->SetY(T[1]);
      par->SetZ(T[5]);
      par->SetTx(T[2]);
      par->SetTy(T[3]);
      par->SetQp(T[4]);
    }
    if (C) {
      for (Int_t i = 0, iCov = 0; i < 5; i++)
        for (Int_t j = 0; j <= i; j++, iCov++)
          par->SetCovariance(i, j, C[iCov]);
    }
  }

  void CopyTrackParam2TC(const FairTrackParam* par, Double_t T[], Double_t C[])
  {
    if (T) {
      T[0] = par->GetX();
      T[1] = par->GetY();
      T[2] = par->GetTx();
      T[3] = par->GetTy();
      T[4] = par->GetQp();
      T[5] = par->GetZ();
    }
    if (C) {
      for (Int_t i = 0, iCov = 0; i < 5; i++)
        for (Int_t j = 0; j <= i; j++, iCov++)
          C[iCov] = par->GetCovariance(i, j);
    }
  }

}  // namespace cbm::L1Util
